class Organization:
    """
    Get organization information.

    Args:

        Carol object
            Carol object.
    """

    def __init__(self, carol):

        self.carol = carol

    def get_organization_info(self, organization):
        """
        Get organization information.

        :param organization: `str`
            Organization subdomain
        :return:
            dict with the information about the organization.
        """

        return self.carol.call_api(f'v1/organizations/domain/{organization}',
                                   auth=False, status_forcelist=[], retries=0)


    def get_environment_info(self, environment):
        """
        Get environment information.

        :param environment: `str`
            Tenant name
        :return:
            dict with the information about the environment.
        """
        return self.carol.call_api(f'v2/tenants/domain/{environment}',
                                   auth=False, status_forcelist=[], retries=0)



""" PyCarol - Connecting Carol to Python

"""

import os
import tempfile

__version__ = '2.34.2'

__TEMP_STORAGE__ = os.path.join(tempfile.gettempdir(), 'carolina/cache')

__CONNECTOR_PYCAROL__ = 'f9953f6645f449baaccd16ab462f9b64'

_CAROL_METADATA_STAGING = ['mdmCounterForEntity', 'mdmId', 'mdmLastUpdated',
                           'mdmConnectorId', 'mdmDeleted']

_CAROL_METADATA_GOLDEN = ['mdmApplicationIdMasterRecordId', 'mdmCounterForEntity', 'mdmCreated',  'mdmCrosswalk',
                          'mdmDeleted', 'mdmEntityType',  'mdmId',  'mdmLastUpdated', 'mdmSourceEntityNames',
                          'mdmStagingRecord', 'mdmTenantId']

_NEEDED_FOR_MERGE = ['mdmCounterForEntity', 'mdmId', 'mdmDeleted']

from .carol import Carol
from .staging import Staging
from .connectors import Connectors
from .query import Query
from .storage import Storage
from .carolina import Carolina
from .tasks import Tasks
from .data_models import DataModel, DataModelView
from .logger import CarolHandler
from .auth.PwdAuth import PwdAuth
from .auth.ApiKeyAuth import ApiKeyAuth
from .auth.PwdKeyAuth import PwdKeyAuth
from .cds import CDSGolden, CDSStaging
from .apps import Apps
